from setuptools import setup, find_packages

setup(
    name='dotprompt',
    version='0.1.8',
    packages=find_packages(),
    install_requires=[
        # Liste des dépendances de votre bibliothèque
    ],
)